@@ -15,6 +15,7 @@ import markupsafe
 from bs4 import BeautifulSoup
 from jupyter_core.paths import jupyter_path
 from traitlets import Bool, Unicode, default, validate
+from traitlets import Dict as TraitletsDict
 from traitlets.config import Config
 
 if tuple(int(x) for x in jinja2.__version__.split(".")[:3]) < (3, 0, 0):
@@ -124,7 +125,7 @@ class HTMLExporter(TemplateExporter):
     ).tag(config=True)
 
     mermaid_js_url = Unicode(
-        "https://cdnjs.cloudflare.com/ajax/libs/mermaid/10.6.0/mermaid.esm.min.mjs",
+        "https://cdnjs.cloudflare.com/ajax/libs/mermaid/10.7.0/mermaid.esm.min.mjs",
         help="""
         URL to load MermaidJS from.
 
@@ -172,12 +173,25 @@ class HTMLExporter(TemplateExporter):
         ),
     ).tag(config=True)
 
+    skip_svg_encoding = Bool(
+        False,
+        help=("Whether the svg to image data attribute encoding should occur"),
+    ).tag(config=True)
+
     embed_images = Bool(
         False, help="Whether or not to embed images as base64 in markdown cells."
     ).tag(config=True)
 
     output_mimetype = "text/html"
 
+    lexer_options = TraitletsDict(
+        {},
+        help=(
+            "Options to be passed to the pygments lexer for highlighting markdown code blocks. "
+            "See https://pygments.org/docs/lexers/#available-lexers for available options."
+        ),
+    ).tag(config=True)
+
     @property
     def default_config(self):
         c = Config(
@@ -213,8 +227,9 @@ class HTMLExporter(TemplateExporter):
     def _valid_language_code(self, proposal):
         if self.language_code not in iso639_1:
             self.log.warning(
-                f'"{self.language_code}" is not an ISO 639-1 language code. '
-                'It has been replaced by the default value "en".'
+                '"%s" is not an ISO 639-1 language code. '
+                'It has been replaced by the default value "en".',
+                self.language_code,
             )
             return proposal["trait"].default_value
         return proposal["value"]
@@ -233,6 +248,7 @@ class HTMLExporter(TemplateExporter):
             path=path,
             anchor_link_text=self.anchor_link_text,
             exclude_anchor_links=self.exclude_anchor_links,
+            **self.lexer_options,
         )
         return MarkdownWithMath(renderer=renderer).render(source)
 
@@ -251,6 +267,8 @@ class HTMLExporter(TemplateExporter):
             "highlight_code", Highlight2HTML(pygments_lexer=lexer, parent=self)
         )
 
+        resources = self._init_resources(resources)
+
         filter_data_type = WidgetsDataTypeFilter(
             notebook_metadata=self._nb_metadata, parent=self, resources=resources
         )
@@ -265,7 +283,7 @@ class HTMLExporter(TemplateExporter):
             elem.attrs["alt"] = "No description has been provided for this image"
             missing_alt += 1
         if missing_alt:
-            self.log.warning(f"Alternative text is missing on {missing_alt} image(s).")
+            self.log.warning("Alternative text is missing on %s image(s).", missing_alt)
         # Set input and output focusable
         for elem in soup.select(".jp-Notebook div.jp-Cell-inputWrapper"):
             elem.attrs["tabindex"] = "0"
@@ -274,7 +292,7 @@ class HTMLExporter(TemplateExporter):
 
         return str(soup), resources
 
-    def _init_resources(self, resources):  # noqa
+    def _init_resources(self, resources):
         def resources_include_css(name):
             env = self.environment
             code = """<style type="text/css">\n%s</style>""" % (env.loader.get_source(env, name)[0])
@@ -351,4 +369,5 @@ class HTMLExporter(TemplateExporter):
         resources["html_manager_semver_range"] = self.html_manager_semver_range
         resources["should_sanitize_html"] = self.sanitize_html
         resources["language_code"] = self.language_code
+        resources["should_not_encode_svg"] = self.skip_svg_encoding
         return resources
